@@ -29,6 +29,7 @@
 #include "document.h"
 #include "electron.h"
 #include "fragment.h"
+#include "gcp-stock-pixbufs.h"
 #include "text.h"
 #include "plugin.h"
 #include "mesomer.h"
@@ -51,12 +52,6 @@
 #include "zoomdlg.h"
 #include <gcu/filechooser.h>
 #include <gcu/loader.h>
-#include <goffice/utils/go-file.h>
-#include <goffice/goffice.h>
-#ifndef HAVE_GO_CONF_SYNC
-#	include <gconf/gconf-client.h>
-#endif
-#include <gio/gio.h>
 #include <glib/gi18n-lib.h>
 #include <openbabel/mol.h>
 #include <openbabel/reaction.h>
@@ -251,17 +246,10 @@ bool	Application::m_bInit = false;
 bool	Application::m_Have_Ghemical = false;
 bool	Application::m_Have_InChI = false;
 
-#ifdef HAVE_GO_CONF_SYNC
 static void on_config_changed (GOConfNode *node, gchar const *key, Application *app)
 {
 	app->OnConfigChanged (node, key);
 }
-#else
-static void on_config_changed (GConfClient *client, guint cnxn_id, GConfEntry *entry, Application *app)
-{
-	app->OnConfigChanged (client, cnxn_id, entry);
-}
-#endif
 
 Application::Application ():
 	gcu::Application ("GChemPaint", DATADIR, "gchempaint", "gchempaint")
@@ -393,22 +381,13 @@ Application::Application ():
 		}
 	}
 	
-#ifdef HAVE_GO_CONF_SYNC
 	m_ConfNode = go_conf_get_node (GetConfDir (), GCP_CONF_DIR_SETTINGS);
-#else
-	GError *error = NULL;
-	m_ConfClient = gconf_client_get_default ();
-#endif
 	GCU_GCONF_GET ("compression", int, CompressionLevel, 0)
 	GCU_GCONF_GET ("tearable-mendeleiev", bool, TearableMendeleiev, false)
 	bool CopyAsText;
 	GCU_GCONF_GET ("copy-as-text", bool, CopyAsText, false)
 	ClipboardFormats = CopyAsText? GCP_CLIPBOARD_ALL: GCP_CLIPBOARD_NO_TEXT;
-#ifdef HAVE_GO_CONF_SYNC
 	m_NotificationId = go_conf_add_monitor (m_ConfNode, NULL, (GOConfMonitorFunc) on_config_changed, this);
-#else
-	m_NotificationId = gconf_client_notify_add (m_ConfClient, "/apps/gchemutils/paint/settings", (GConfClientNotifyFunc) on_config_changed, this, NULL, NULL);
-#endif
 	// make themes permanent with this as a dummy client
 	list <string> Names = TheThemeManager.GetThemesNames ();
 	list <string>::iterator j, jend = Names.end ();
@@ -418,6 +397,11 @@ Application::Application ():
 		pTheme = TheThemeManager.GetTheme (*j);
 		pTheme->AddClient (m_Dummy);
 	}
+	// Create cursors
+	GdkPixbuf *unallowed = gdk_pixbuf_new_from_inline (-1, gcp_unallowed, false, NULL);
+	m_Cursors[CursorUnallowed] = gdk_cursor_new_from_pixbuf (gdk_display_get_default (), unallowed, 3, 3);
+	g_object_unref (unallowed);
+	m_Cursors[CursorPencil] = gdk_cursor_new (GDK_PENCIL);
 }
 
 Application::~Application ()
@@ -438,16 +422,13 @@ Application::~Application ()
 		pTheme->RemoveClient (m_Dummy);
 	}
 	delete m_Dummy;
-#ifdef HAVE_GO_CONF_SYNC
 	go_conf_remove_monitor (m_NotificationId);
 	go_conf_free_node (m_ConfNode);
 	m_ConfNode = NULL;
-#else
-	gconf_client_notify_remove (m_ConfClient, m_NotificationId);
-	g_object_unref (m_ConfClient);
-	m_ConfClient = NULL;
-#endif
 	TheThemeManager.Shutdown ();
+	// unref cursors
+	for (int i = 0; i < CursorMax; i++)
+		gdk_cursor_unref (m_Cursors[i]);
 }
 
 void Application::ActivateTool (const string& toolname, bool activate)
@@ -628,7 +609,7 @@ bool Application::FileProcess (const gchar* filename, const gchar* mime_type, bo
 				m_pActiveDoc->ExportImage (filename2, pixbuf_type, GetImageResolution ());
 				break;
 			default:
-				if (Save (filename2, mime_type, pDoc));
+				if (Save (filename2, mime_type, pDoc, ContentType2D));
 				else if (!strcmp (mime_type, "application/x-gchempaint"))
 					SaveGcp (filename2, pDoc);
 				else
@@ -663,7 +644,37 @@ bool Application::FileProcess (const gchar* filename, const gchar* mime_type, bo
 			pDoc = m_pActiveDoc;
 		}
 		pDoc->SetFileName(filename2, mime_type);
-		if (Load (filename2, mime_type, pDoc)) {
+		ContentType type = Load (filename2, mime_type, pDoc);
+		if (type != ContentTypeUnknown) {
+			switch (type) {
+			case ContentType3D: {
+				// open in gchem3d instead
+				string command = string ("gchem3d-") + API_VERSION + " " + filename2;
+				g_spawn_command_line_async (command.c_str (), NULL);
+				if (create) {
+					pDoc->GetWindow ()->Destroy ();
+					pDoc = NULL;
+					} else
+					pDoc->Clear ();
+				return false;
+			}
+			case ContentTypeCrystal:
+				break;
+			case ContentTypeSpectrum:
+				break;
+			default: {
+				double l = pDoc->GetMedianBondLength ();
+				if (l > 0.) {
+					double r = pDoc->GetBondLength () / l;
+					if (fabs (r - 1.) > .1) { // might not work properly in some rare cases when there are a lot of short or long bonds
+						Matrix2D m (r, 0., 0., r);
+						// FIXME: this would not work for reactions
+						pDoc->Transform2D (m, 0., 0.);
+					}
+				}
+				break;
+			}
+			};
 			pDoc->GetView ()->AddObject (pDoc);
 			pDoc->GetView ()->Update (pDoc);
 			pDoc->GetView ()->EnsureSize ();
@@ -671,7 +682,7 @@ bool Application::FileProcess (const gchar* filename, const gchar* mime_type, bo
 				pDoc->GetWindow ()->ActivateActionWidget ("/MainMenu/FileMenu/SaveAsImage", pDoc->HasChildren ());
 		} else {
 			if (create) {
-				pDoc->GetWindow ()->Destroy ();;
+				pDoc->GetWindow ()->Destroy ();
 				pDoc = NULL;
 				while (gdk_events_pending ())
 					gtk_main_iteration ();
@@ -885,6 +896,7 @@ void Application::OpenGcp (string const &filename, Document* pDoc)
 			g_error_free (error);
 			throw 1;
 		}
+		xmlKeepBlanksDefault (1); // to be sure we don't loose significant spaces.
 		if (!(xml = xmlReadIO ((xmlInputReadCallback) cb_vfs_to_xml, 
 				 (xmlInputCloseCallback) g_input_stream_close, input, filename.c_str (), NULL, 0))) {
 			g_object_unref (file);
@@ -1002,7 +1014,7 @@ void Application::Zoom (double zoom)
 	}
 }
 
-static void on_tool_changed (GtkAction *action, GtkAction *current, Application* App)
+static void on_tool_changed (G_GNUC_UNUSED GtkAction *action, GtkAction *current, Application* App)
 {
 	App->OnToolChanged (current);
 }
@@ -1033,7 +1045,7 @@ void Application::OnToolChanged (GtkAction *current)
 		m_pActiveTool->Activate(true);
 }
 
-void Application::BuildTools ()
+void Application::BuildTools () throw (std::runtime_error)
 {
 	Tools *ToolsBox = new Tools (this);
 	map<int, string>::iterator i, iend = ToolbarNames.end ();
@@ -1048,9 +1060,9 @@ void Application::BuildTools ()
 	gtk_ui_manager_insert_action_group (ToolsManager, action_group, 0);
 	for (j = UiDescs.begin (); j != jend; j++)
 		if (!gtk_ui_manager_add_ui_from_string (ToolsManager, *j, -1, &error)) {
-			g_message ("building user interface failed: %s", error->message);
+			string what = string ("building user interface failed: ") + error->message;
 			g_error_free (error);
-			exit (EXIT_FAILURE);
+			throw runtime_error (what);
 		}
 	for (i = ToolbarNames.begin (); i != iend; i++) {
 		s = "ui/";
@@ -1195,17 +1207,8 @@ void Application::ActivateWindowsActionWidget (const char *path, bool activate)
 	}
 }
 
-#ifdef HAVE_GO_CONF_SYNC
 void Application::OnConfigChanged (GOConfNode *node, gchar const *name)
 {
-#else
-void Application::OnConfigChanged (GConfClient *client, guint cnxn_id, GConfEntry *entry)
-{
-	if (client != m_ConfClient)
-		return;	// we might want an error message?
-	if (cnxn_id != m_NotificationId)
-		return;	// we might want an error message?
-#endif
 	GCU_UPDATE_KEY ("compression", int, CompressionLevel, {})
 	GCU_UPDATE_KEY ("tearable-mendeleiev", bool, TearableMendeleiev,
 					{
@@ -1266,26 +1269,6 @@ void Application::BuildMenu (GtkUIManager *manager)
 		(*i) (manager);
 }
 
-struct option_data {
-	GOptionEntry const *entries;
-	char const *translation_domain;
-};
-
-void Application::RegisterOptions (GOptionEntry const *entries, char const *translation_domain)
-{
-	struct option_data d;
-	d.entries = entries;
-	d.translation_domain = translation_domain;
-	m_Options.push_back (d);
-}
-
-void Application::AddOptions (GOptionContext *context)
-{
-	list<option_data>::iterator i, end = m_Options.end ();
-	for (i = m_Options.begin (); i != end; i++)
-		g_option_context_add_main_entries (context, (*i).entries, (*i).translation_domain);
-}
-
 gcu::Document *Application::CreateNewDocument ()
 {
 	return new Document (this, true, NULL);
