@@ -75,6 +75,7 @@ Atom::Atom ():
 	m_Layout = m_ChargeLayout = m_HLayout = NULL;
 	m_DrawCircle = false;
 	m_SWidth = 0.;
+	m_ChargeItem = NULL;
 }
 
 Atom::~Atom ()
@@ -119,6 +120,7 @@ Atom::Atom (int Z, double x, double y, double z):
 	m_Layout = m_ChargeLayout = m_HLayout = NULL;
 	m_DrawCircle = false;
 	m_SWidth = 0.;
+	m_ChargeItem = NULL;
 }
 
 Atom::Atom (OBAtom* atom):
@@ -149,6 +151,7 @@ Atom::Atom (OBAtom* atom):
 	m_DrawCircle = false;
 	m_Charge = atom->GetFormalCharge ();
 	m_SWidth = 0.;
+	m_ChargeItem = NULL;
 }
 
 void Atom::SetZ (int Z)
@@ -1017,7 +1020,7 @@ void Atom::UpdateAvailablePositions ()
 	m_AvailPosCached = true;
 }
 
-int Atom::GetChargePosition (unsigned char& Pos, double Angle, double& x, double& y)
+gccv::Anchor Atom::GetChargePosition (unsigned char& Pos, double Angle, double& x, double& y)
 {
 	list<double>::iterator n, end;
 	double angle;
@@ -1072,7 +1075,7 @@ int Atom::GetChargePosition (unsigned char& Pos, double Angle, double& x, double
 		} 
 	} else if (Pos) {
 		if (!(Pos & m_AvailPos) && (Pos != m_ChargePos))
-			return 0;
+			return gccv::AnchorCenter;
 	} else {
 		if (Angle > 360.)
 			Angle -= 360;
@@ -1081,74 +1084,74 @@ int Atom::GetChargePosition (unsigned char& Pos, double Angle, double& x, double
 		if (!(((GetZ() == 6) && (m_Bonds.size() != 0)) ||
 			 !m_nH || ((!m_HPos && (Angle < 135. || Angle > 225.)) ||
 				(m_HPos && (Angle > 45. && Angle < 315.)))))
-			return 0;
+			return gccv::AnchorCenter;
 	}
 	switch (Pos) {
 	case POSITION_NE:
 		x = m_x + m_width / 2.0;
 		y = m_y - m_height / 2.0;
-		return 1;
+		return gccv::AnchorWest;
 	case POSITION_NW:
 		x = m_x - m_width / 2.0;
 		y = m_y - m_height / 2.0;
-		return -1;
+		return gccv::AnchorEast;
 	case POSITION_N:
 		x = m_x;
 		y = m_y - m_height / 2.0;
-		return 2;
+		return gccv::AnchorSouth;
 	case POSITION_SE:
 		x = m_x + m_width / 2.0;
 		y = m_y + m_height / 2.0;
-		return 1;
+		return gccv::AnchorWest;
 	case POSITION_SW:
 		x = m_x - m_width / 2.0;
 		y = m_y + m_height / 2.0;
-		return -1;
+		return gccv::AnchorEast;
 	case POSITION_S:
 		x = m_x;
 		y = m_y + m_height / 2.0;
-		return -2;
+		return gccv::AnchorNorth;
 	case POSITION_E:
 		x = m_x + m_width / 2.0;
 		y = m_y;
-		return 1;
+		return gccv::AnchorWest;
 	case POSITION_W:
 		x = m_x - m_width / 2.0;
 		y = m_y;
-		return -1;
+		return gccv::AnchorEast;
 	default: {
 			double t = tan (Angle / 180. * M_PI);
 			double limit = atan (m_height / m_width) * 180. / M_PI;
 			if (Angle < limit) {
 				x = m_x /*+  12. */+ m_width / 2.;
 				y = m_y - m_width / 2. * t;
-				return 1;
+				return gccv::AnchorWest;
 			} else if (Angle < 180. - limit) {
 				if (!isnan (t))
 					x = m_x + m_height / 2. / t;
 				else
 					x = m_x;
 				y = m_y - m_height / 2.;
-				return 2;
+				return gccv::AnchorSouth;
 			} else if (Angle < 180. + limit) {
 				x = m_x /*- 12.*/ - m_width / 2.;
 				y = m_y + m_width / 2. * t;
-				return -1;
+				return gccv::AnchorEast;
 			} else if (Angle < 360. - limit) {
 				if (!isnan (t))
 					x = m_x - m_height / 2. / t;
 				else
 					x = m_x;
 				y = m_y + m_height / 2.;
-				return -2;
+				return gccv::AnchorNorth;
 			} else {
 				x = m_x /*+  12.*/ + m_width / 2.;
 				y = m_y - m_width / 2. * t;
-				return 1;
+				return gccv::AnchorWest;
 			}
 		}			
 	}
-	return 0; // should not occur
+	return gccv::AnchorCenter; // should not occur
 }
 
 int Atom::GetAvailablePosition (double& x, double& y)
@@ -1238,7 +1241,7 @@ void Atom::SetSelected (int state)
 	default:
 	case SelStateUnselected:
 		textcolor = 0;
-		othercolor = RGBA_BLACK;
+		othercolor = GO_COLOR_BLACK;
 		break;
 	case SelStateSelected:
 		othercolor = textcolor = SelectColor;
@@ -1255,7 +1258,10 @@ void Atom::SetSelected (int state)
 	gccv::Item *item = group->GetFirstChild (it);
 	while (item) {
 		gccv::FillItem *fill;
-		if ((fill = dynamic_cast <gccv::Rectangle *> (item)))
+		gccv::Text *text;
+		if ((text = dynamic_cast <gccv::Text *> (item)))
+			text->SetColor (othercolor);
+		else if ((fill = dynamic_cast <gccv::Rectangle *> (item)))
 			fill->SetFillColor (textcolor);
 		else if ((fill = dynamic_cast <gccv::FillItem *> (item)))
 			fill->SetFillColor (othercolor);
@@ -1534,7 +1540,7 @@ bool Atom::MayHaveImplicitUnpairedElectrons ()
 			&& (((m_Element->GetValenceElectrons() - m_Charge) > nel) || m_ChargeAuto);
 }
 
-bool Atom::GetPosition(double angle, double& x, double& y)
+bool Atom::GetPosition (double angle, double& x, double& y)
 {
 	if (angle > 360.)
 		angle -= 360;
@@ -1548,7 +1554,7 @@ bool Atom::GetPosition(double angle, double& x, double& y)
 		double t = tan (angle / 180. * M_PI);
 		double limit = atan (m_height / m_width) * 180. / M_PI;
 		if (angle < limit) {
-			x = m_x +  12. + m_width / 2.;
+			x = m_x + m_width / 2.;
 			y = m_y - m_width / 2. * t;
 		} else if (angle < 180. - limit) {
 			if (!isnan (t))
@@ -1557,7 +1563,7 @@ bool Atom::GetPosition(double angle, double& x, double& y)
 				x = m_x;
 			y = m_y - m_height / 2.;
 		} else if (angle < 180. + limit) {
-			x = m_x - 12. - m_width / 2.;
+			x = m_x - m_width / 2.;
 			y = m_y + m_width / 2. * t;
 		} else if (angle < 360. - limit) {
 			if (!isnan (t))
@@ -1566,7 +1572,7 @@ bool Atom::GetPosition(double angle, double& x, double& y)
 				x = m_x;
 			y = m_y + m_height / 2.;
 		} else {
-			x = m_x +  12. + m_width / 2.;
+			x = m_x + m_width / 2.;
 			y = m_y - m_width / 2. * t;
 		}			
 		return true;
@@ -1839,7 +1845,17 @@ static void do_display_symbol (GtkToggleAction *action, Atom *pAtom)
 	pAtom->EmitSignal (OnChangedSignal);
 	Op->AddObject (Obj, 1);
 	Doc->FinishOperation ();
-	Doc->GetView ()->Update (pAtom);
+	View *view = Doc->GetView ();
+	view->Update (pAtom);
+	// also update the bonds
+	map<gcu::Atom*, gcu::Bond*>::iterator i;
+	Bond *bond = static_cast <Bond *> (pAtom->GetFirstBond (i));
+	while (bond) {
+		bond->SetDirty ();
+		view->Update (bond);
+		bond = static_cast <Bond *> (pAtom->GetNextBond (i));
+	}
+	
 }
 
 static void do_choose_H_pos (Atom* Atom)
@@ -1910,8 +1926,8 @@ void Atom::GetSymbolGeometry (double &width, double &height, double &angle, bool
 void Atom::BuildSymbolGeometry (double width, double height, double ascent)
 {
 	m_SWidth = width / 2.;
-	m_SHeightH = ascent;
-	m_SHeightL = height - m_SHeightH;
+	m_SHeightH = ascent + 1.; // we use ink extent vertically and logical extent horizonatlly
+	m_SHeightL = height - m_SHeightH + 2.;
 	m_SAngleH = atan2 (m_SHeightH, m_SWidth);
 	m_SAngleL = atan2 (m_SHeightL, m_SWidth);
 }
@@ -1931,20 +1947,21 @@ void Atom::AddItem ()
 	gccv::Group *group = new gccv::Group (view->GetCanvas ()->GetRoot (), x, y, this);
 	if ((GetZ() != 6) || (GetBondsNumber() == 0) || m_ShowSymbol) {
 		gccv::Text *text = new gccv::Text (group, 0., 0., this);
-		text->SetFillColor ((view->GetData ()->IsSelected (this))? SelectColor: 0);
+		text->SetColor ((view->GetData ()->IsSelected (this))? SelectColor: GO_COLOR_BLACK);
 		text->SetPadding (theme->GetPadding ());
 		text->SetLineColor (0);
 		text->SetLineWidth (0.);
+		text->SetFillColor (0);
 		text->SetFontDescription (view->GetPangoFontDesc ());
 		text->SetText (GetSymbol ());
 		text->SetLineOffset (view->GetCHeight ());
 		// build the symbol geometry
-		BuildSymbolGeometry (text->GetWidth (), text->GetHeight (), text->GetAscent () - text->GetY () - view->GetCHeight ());		
 		int n = GetAttachedHydrogens ();
 		gccv::Rect ink, logical;
 		text->GetBounds (&ink, &logical);
-		m_width = (logical.x1 - logical.x0 + 2 * theme->GetPadding ()) / theme->GetZoomFactor ();
-		m_height = (logical.y1 - logical.y0 + 2 * theme->GetPadding ()) / theme->GetZoomFactor ();
+		BuildSymbolGeometry (text->GetWidth (), ink.y1 - ink.y0, /*text->GetAscent () - view->GetCHeight ()*/ - ink.y0);		
+		m_width = (ink.x1 - ink.x0 + 2 * theme->GetPadding ()) / theme->GetZoomFactor ();
+		m_height = (ink.y1 - ink.y0 + 2 * theme->GetPadding ()) / theme->GetZoomFactor ();
 		if (n > 0) {
 			string hs = "H";
 			if (n > 1) {
@@ -1953,10 +1970,11 @@ void Atom::AddItem ()
 				g_free (str);
 			}
 			text = new gccv::Text (group, 0., 0., this);
-			text->SetFillColor ((view->GetData ()->IsSelected (this))? SelectColor: 0);
+			text->SetColor ((view->GetData ()->IsSelected (this))? SelectColor: GO_COLOR_BLACK);
 			text->SetPadding (theme->GetPadding ());
 			text->SetLineColor (0);
 			text->SetLineWidth (0.);
+			text->SetFillColor (0);
 			text->SetFontDescription (view->GetPangoFontDesc ());
 			text->SetText (hs.c_str ());
 			if (n >1) {
@@ -1987,77 +2005,12 @@ void Atom::AddItem ()
 				g_critical ("This should not happen, please file a bug report");
 				break;
 			}
-/*			pango_layout_set_text (m_HLayout, "H", -1);
-			pango_layout_get_extents (m_HLayout, &HRect, NULL);
-			switch (m_HPos) {
-			case LEFT_HPOS:
-				//the x offset needs to be calculated after adding possible stoichimoetry.
-				m_xHOffs = m_yHOffs = 0.;
-				break;
-			case RIGHT_HPOS:
-				m_xHOffs = rect.width / PANGO_SCALE + 1.;
-				m_yHOffs = 0.;
-				break;
-			case TOP_HPOS:
-				m_xHOffs = m_lbearing - pTheme->GetPadding () - HRect.width / PANGO_SCALE / 2.;
-				break;
-			case BOTTOM_HPOS:
-				m_xHOffs = m_lbearing - pTheme->GetPadding () - HRect.width / PANGO_SCALE / 2.;
-				m_yHOffs = m_CHeight * 2. + pTheme->GetPadding ();
-				break;
-			default:
-				g_critical ("This should not happen, please file a bug report");
-				break;
-			}
-			if (n > 1) {
-				gchar const *nb =  g_strdup_printf ("%d", n);
-				int nw = strlen (nb);
-				PangoAttrList *pal = pango_attr_list_new ();
-				text = g_strconcat ("H", nb, NULL);
-				pango_layout_set_text (m_HLayout, text, -1);
-				nw = strlen (text);
-				PangoAttribute *attr = pango_attr_font_desc_new (pView->GetPangoSmallFontDesc());
-				attr->start_index = 1;
-				attr->end_index = strlen (text);
-				pango_attr_list_insert (pal, attr);
-				attr = pango_attr_rise_new (-2 * PANGO_SCALE);
-				attr->start_index = 1;
-				attr->end_index = nw;
-				pango_attr_list_insert (pal, attr);
-				pango_layout_set_attributes (m_HLayout, pal);
-				pango_attr_list_unref (pal);
-			}
-			pango_layout_get_extents (m_HLayout, &HRect, NULL);
-			// evaluate underlying rectangle size and position
-			if (HRect.width > 0) {
-				switch (m_HPos) {
-				case LEFT_HPOS:
-					m_xHOffs = -HRect.width / PANGO_SCALE - 1.;
-					m_xROffs = m_xHOffs;
-					m_length += HRect.width / PANGO_SCALE + 1.;
-					break;
-				case RIGHT_HPOS:
-					m_length += HRect.width / PANGO_SCALE + 1.;
-					break;
-				case TOP_HPOS:
-					m_yHOffs = -HRect.height / PANGO_SCALE - pTheme->GetPadding ();
-					m_yROffs = -HRect.height / PANGO_SCALE - pTheme->GetPadding ();
-					m_text_height += HRect.height / PANGO_SCALE + pTheme->GetPadding ();
-					m_length = MAX (m_length, HRect.width / PANGO_SCALE);
-					break;
-				case BOTTOM_HPOS:
-					m_text_height += HRect.height / PANGO_SCALE + pTheme->GetPadding ();
-					m_length = MAX (m_length, HRect.width / PANGO_SCALE);
-					break;
-				default:
-					break;
-				}
-			}*/
 		}
 	} else {
 		gccv::FillItem *fill = new gccv::Rectangle (group,  -3., -3., 6., 6., this);
 		fill->SetFillColor ((view->GetData ()->IsSelected (this))? SelectColor: 0);
 		fill->SetLineColor (0);
+		m_width = m_height = 2 * theme->GetPadding () / theme->GetZoomFactor ();
 		if (m_DrawCircle) {
 			fill = new gccv::Circle ( group, 0., 0., theme->GetStereoBondWidth () / 2., this);
 			fill->SetFillColor ((view->GetData ()->IsSelected (this))? SelectColor: Color);
@@ -2065,6 +2018,36 @@ void Atom::AddItem ()
 		}
 	}
 	m_Item = group;
+	int charge = GetCharge ();
+	if (charge) {
+		gccv::Anchor anchor = GetChargePosition (m_ChargePos, m_ChargeAngle * 180 / M_PI, x, y);
+		if (m_ChargeDist != 0.) {
+			anchor = gccv::AnchorCenter;
+			x = m_ChargeDist * cos (m_ChargeAngle);
+			y = m_ChargeDist * sin (m_ChargeAngle);
+		}
+		x -= m_x;
+		x *= theme->GetZoomFactor ();
+		y -= m_y;
+		y *= theme->GetZoomFactor ();
+		char* markup = NULL;
+		char const *glyph = (charge > 0)? "\xE2\x8a\x95": "\xE2\x8a\x96";
+		if (abs (m_Charge) > 1)
+			markup = g_strdup_printf ("%d%s", abs (m_Charge), glyph);
+		else
+			markup = g_strdup (glyph);
+		gccv::Text *text = new gccv::Text (group, x, y, NULL);
+		text->SetFillColor (0);
+		text->SetPadding (theme->GetPadding ());
+		text->SetLineColor (0);
+		text->SetLineWidth (0.);
+		text->SetAnchor (anchor);
+		text->SetFontDescription (view->GetPangoSmallFontDesc ());
+		text->SetText (markup);
+		m_ChargeItem = text;
+		g_free (markup);
+	} else
+		m_ChargeItem = NULL;
 }
 
 bool Atom::HasAvailableElectrons (bool paired)
