@@ -28,6 +28,7 @@
 #include <map>
 #include <glib.h>
 #include <gccv/item-client.h>
+#include <gccv/structs.h>
 #include <gcu/atom.h>
 #include <gcu/dialog-owner.h>
 #include <gcu/element.h>
@@ -182,15 +183,10 @@ arranged.
 On input \a Pos can be one of POSITION_E, POSITION_N,... or 0xff, in which case,
 it will be given a default value. \a x and \a y are set to the position where the charge
 sign should be displayed usding the alignment code returned by this method.
-@return a number to set how the charge symbol should be aligned relative to its
-position. Possible values are:
-- −2: center top.
-- −1: right.
--  0: center.
--  1: left.
--  2: center bottom.
+@return the anchor for the charge symbol. On error, gccv::AnchorCenter is used as
+the returned value.
 */
-	virtual int GetChargePosition (unsigned char& Pos, double Angle, double& x, double& y);
+	virtual gccv::Anchor GetChargePosition (unsigned char& Pos, double Angle, double& x, double& y);
 /*!
 @param x the x position.
 @param y the y position.
@@ -365,6 +361,8 @@ This method is used to avoid bonds lines extyending over their atoms symbols.
 */
 	void GetSymbolGeometry (double &width, double &height, double &angle, bool up) const;
 
+	bool HasAvailableElectrons (bool paired);
+
 protected:
 /*!
 @param width the witdh of the atomic symbol.
@@ -442,6 +440,8 @@ Sets the position of attached hydrogen atoms symbol.
 @return the position of attached hydrogen atoms symbol as a reference.
 */
 GCU_PROP (HPos, HPosStyle) //0=force left, 1=force right, 2=force top, 3=force bottom, 4=auto.
+GCU_PROP (gccv::Item *, ChargeItem) //0=force left, 1=force right, 2=force top, 3=force bottom, 4=auto.
+
 };
 
 }	//	namespace gcp
