@@ -39,7 +39,8 @@ namespace gcp {
 
 extern xmlDocPtr pXmlDoc;
 
-TextObject::TextObject (TypeId Type): Object (Type), gccv::TextClient ()
+TextObject::TextObject (TypeId Type): Object (Type), gccv::TextClient (),
+	m_TextItem (NULL)
 {
 	m_x = 0.;
 	m_y = 0.;
@@ -54,7 +55,8 @@ TextObject::TextObject (TypeId Type): Object (Type), gccv::TextClient ()
 }
 
 TextObject::TextObject (double x, double y, TypeId Type): Object (Type),
-	gccv::TextClient ()
+	gccv::TextClient (),
+	m_TextItem (NULL)
 {
 	m_x = x;
 	m_y = y;
@@ -179,7 +181,9 @@ void TextObject::TextChanged (unsigned pos)
 {
 	OnChanged (true);
 	// call SelectionChanged after OnChanged so that we can know what was selected before the text change
-	SelectionChanged (pos, pos);
+	unsigned start;
+	m_TextItem->GetSelectionBounds (start, pos);
+	SelectionChanged (start, pos);
 }
 
 }	//	namespace gcp
