@@ -25,6 +25,7 @@
 #ifndef GCHEMPAINT_TOOL_H
 #define GCHEMPAINT_TOOL_H
 
+#include <gcu/macros.h>
 #include <gtk/gtk.h>
 #include <libxml/tree.h>
 #include <vector>
@@ -178,12 +179,19 @@ m_nState, and calls Tool::OnChangeState ().
 */
 	void OnKeyReleased (unsigned int code) {if (m_nState & code) m_nState -= code; OnChangeState ();}
 /*!
-Called by the framework for the active tool when an event occurs. Default
+Called by the framework for the active tool when a key press event occurs. Default
 just returns \a false.
 
 @return true to stop any further propagation of the event, false otherwise.
 */
-	virtual bool OnEvent (GdkEvent* event);
+	virtual bool OnKeyPress (GdkEventKey *event);
+/*!
+Called by the framework for the active tool when a key release event occurs. Default
+just returns \a false.
+
+@return true to stop any further propagation of the event, false otherwise.
+*/
+	virtual bool OnKeyRelease (GdkEventKey *event);
 /*!
 Virtual method called by the framework whenthe active view, and hence the active
 document has changed, so that the tool can finish its current operation in the
@@ -382,6 +390,8 @@ private:
 	double lastx, lasty;
 	std::string name;
 	bool m_bPressed;
+
+GCU_PROT_PROP (bool, OwnStatus)
 };
 
 }	// namespace gcp
