@@ -40,7 +40,6 @@
 #include <gccv/text.h>
 #include <gsf/gsf-output-gio.h>
 #include <gsf/gsf-output-memory.h>
-#include <goffice/utils/go-cairo.h>
 #include <cairo-pdf.h>
 #include <cairo-ps.h>
 #include <cairo-svg.h>
@@ -287,14 +286,10 @@ GtkWidget* View::CreateNewWidget ()
 {
 	if (m_Canvas)
 		return m_Canvas->GetWidget ();
-/*	gtk_widget_push_colormap (gdk_rgb_get_colormap ());
-	m_pWidget = gnome_canvas_gcp_new();
-	gtk_widget_pop_colormap ();*/
 	m_Canvas = new gccv::Canvas (this);
-	m_Canvas->SetBackgroundColor (RGBA_WHITE);
+	m_Canvas->SetBackgroundColor (GO_COLOR_WHITE);
 	m_pWidget = m_Canvas->GetWidget ();
 	m_Canvas->SetGap (3.); // FIXME: make this configurable
-//	GtkWidget* pWidget = (m_Widgets.size() > 0) ? m_Widgets.front () : NULL;
 	if (m_pWidget) {
 		g_object_set_data (G_OBJECT (m_pWidget), "view", this);
 		g_object_set_data (G_OBJECT (m_pWidget), "doc", m_pDoc);
@@ -302,39 +297,10 @@ GtkWidget* View::CreateNewWidget ()
 		m_pData->Canvas = m_pWidget;
 		g_object_set_data (G_OBJECT (m_pWidget), "data", m_pData);
 		m_pData->m_View = this;
-//		gnome_canvas_set_pixels_per_unit (GNOME_CANVAS (m_pWidget), 1);
-//		gnome_canvas_set_scroll_region (GNOME_CANVAS (m_pWidget), 0, 0, m_width, m_height);
 		m_pData->Zoom = 1.0;
-/*		m_pData->Background = gnome_canvas_item_new (
-									gnome_canvas_root (GNOME_CANVAS (m_pWidget)),
-									gnome_canvas_rect_ext_get_type (),
-									"x1", 0.0,
-									"y1", 0.0,
-									"x2", (double) m_width,
-									"y2", (double) m_height,
-									"fill_color", "white",
-									NULL);
-		m_pData->Group = GNOME_CANVAS_GROUP (gnome_canvas_item_new (
-									gnome_canvas_root (GNOME_CANVAS (m_pWidget)),
-									gnome_canvas_group_ext_get_type (),
-									NULL));
-		if (m_pDoc->GetEditable ())
-			g_signal_connect (G_OBJECT (m_pData->Background), "event", G_CALLBACK (on_event), m_pWidget);*/
 		g_signal_connect (G_OBJECT (m_pWidget), "destroy", G_CALLBACK (on_destroy), this);
 		gtk_widget_show (m_pWidget);
-//		m_Widgets.push_back (m_pWidget);
-/*		if (pWidget) {
-			WidgetData* pData = (WidgetData*) g_object_get_data (G_OBJECT (pWidget), "data");
-			std::map<Object const*, GnomeCanvasGroup*>::iterator i, iend = pData->Items.end ();
-			for (i = pData->Items.begin (); i != iend; i++)
-				if ((*i).first->GetType () != gcu::BondType)
-				 (*i).first->Add (m_pWidget);
-			for (i = pData->Items.begin (); i != iend; i++)
-				if ((*i).first->GetType () == gcu::BondType)
-				 (*i).first->Add (m_pWidget);
-		} else*/ {
-			UpdateFont ();
-		}
+		UpdateFont ();
 	}
 	return m_pWidget;
 }
@@ -348,17 +314,6 @@ void View::OnDestroy (GtkWidget* widget)
 		delete m_pDoc;
 }
 
-/*GnomeCanvasItem* View::GetCanvasItem (GtkWidget* widget, Object* Object)
-{
-	WidgetData* pData = reinterpret_cast<WidgetData*> (g_object_get_data (G_OBJECT (widget), "data"));
-	if ((!pData) || (pData->m_View != this))
-		return NULL;
-	GnomeCanvasItem *result = reinterpret_cast<GnomeCanvasItem*> (pData->Items[Object]);
-	if (!result)
-		pData->Items.erase (Object);
-	return result;
-}*/
-
 void View::Update (Object *pObject)
 {
 	gccv::ItemClient *client = dynamic_cast <gccv::ItemClient *> (pObject);
@@ -488,12 +443,14 @@ void View::OnCopySelection (GtkWidget* w, GtkClipboard* clipboard)
 
 void View::OnReceive (GtkClipboard* clipboard, GtkSelectionData* selection_data)
 {
-	if ((selection_data->length <= 0) || !selection_data->data)
+	int length = gtk_selection_data_get_length (selection_data);
+	char const *data = reinterpret_cast <char const *> (gtk_selection_data_get_data (selection_data));
+	if ((length <= 0) || !data)
 		return;
 	Application *pApp = m_pDoc->GetApplication ();
 	Tool *pActiveTool = pApp->GetActiveTool ();
 	guint *DataType = (clipboard == gtk_clipboard_get (GDK_SELECTION_CLIPBOARD))? &ClipboardDataType: &ClipboardDataType1;
-	g_return_if_fail ((selection_data->target == gdk_atom_intern (targets[*DataType].target, FALSE)));
+	g_return_if_fail (gtk_selection_data_get_target (selection_data) == gdk_atom_intern (targets[*DataType].target, FALSE));
 	if (pActiveTool->OnReceive (clipboard, selection_data, *DataType))
 		return;
 	else if (pActiveTool) {
@@ -506,13 +463,13 @@ void View::OnReceive (GtkClipboard* clipboard, GtkSelectionData* selection_data)
 	m_pData->UnselectAll ();
 	switch (*DataType) {
 	case GCP_CLIPBOARD_NATIVE:
-		xml = xmlParseMemory ((const char*) selection_data->data, selection_data->length);
+		xml = xmlParseMemory (data, length);
 		m_pDoc->AddData (xml->children->children);
 		xmlFreeDoc (xml);
 		break;
 	case GCP_CLIPBOARD_UTF8_STRING: {
 			Text* text = new Text ();
-			text->SetText ((char const*) selection_data->data);
+			text->SetText (data);
 			text->OnChanged (true);
 			m_pDoc->AddObject (text);
 			m_pData->SetSelected (text);
@@ -520,13 +477,13 @@ void View::OnReceive (GtkClipboard* clipboard, GtkSelectionData* selection_data)
 		break;
 	case GCP_CLIPBOARD_STRING: {
 			Text* text = new Text ();
-			if (!g_utf8_validate ((const char*) selection_data->data, selection_data->length, NULL)) {
+			if (!g_utf8_validate (data, length, NULL)) {
 				gsize r, w;
-				gchar* newstr = g_locale_to_utf8 ((const char*) selection_data->data, selection_data->length, &r, &w, NULL);
+				gchar* newstr = g_locale_to_utf8 ((const char*) data, length, &r, &w, NULL);
 				text->SetText (newstr);
 				g_free (newstr);
 			} else
-				text->SetText ((char const*) selection_data->data);
+				text->SetText (data);
 			text->OnChanged (true);
 			m_pDoc->AddObject (text);
 			m_pData->SetSelected (text);
@@ -542,15 +499,16 @@ void View::OnReceive (GtkClipboard* clipboard, GtkSelectionData* selection_data)
 	if (clipboard == gtk_clipboard_get (GDK_SELECTION_CLIPBOARD)) {
 		//center the pasted data at the center of the visible area
 		if (m_bEmbedded) {
-			dx = m_pWidget->allocation.width / 2. - (rect.x0 + rect.x1) / 2.;
-			dy = m_pWidget->allocation.height / 2. - (rect.y0 + rect.y1) / 2.;
+			// might this still occur? what does happen if not everything is visible?
+			dx = m_width / 2. - (rect.x0 + rect.x1) / 2.;
+			dy = m_height / 2. - (rect.y0 + rect.y1) / 2.;
 		} else {
 			GtkAdjustment *horiz, *vert;
 			GtkWidget* parent = gtk_widget_get_parent (m_pWidget);
 			horiz = gtk_viewport_get_hadjustment (GTK_VIEWPORT (parent));
 			vert = gtk_viewport_get_vadjustment (GTK_VIEWPORT (parent));
-			dx = horiz->value + horiz->page_size / 2.  - (rect.x0 + rect.x1) / 2.;
-			dy = vert->value + vert->page_size / 2.  - (rect.y0 + rect.y1) / 2.;
+			dx = gtk_adjustment_get_value (horiz) + gtk_adjustment_get_page_size (horiz) / 2.  - (rect.x0 + rect.x1) / 2.;
+			dy = gtk_adjustment_get_value (vert) + gtk_adjustment_get_page_size (vert) / 2.  - (rect.y0 + rect.y1) / 2.;
 		}
 	} else {
 		//center the pasted data at the mouse click position
@@ -630,7 +588,7 @@ bool View::OnKeyPress (GtkWidget* w, GdkEventKey* event)
 {
 	Application *pApp = m_pDoc->GetApplication ();
 	Tool *pActiveTool = pApp->GetActiveTool ();
-	if (pActiveTool->OnEvent ((GdkEvent*) event))
+	if (pActiveTool->OnKeyPress (event))
 		return true;
 	switch (event->keyval) {
 	case GDK_Delete:
@@ -818,6 +776,8 @@ bool View::OnKeyRelease (G_GNUC_UNUSED GtkWidget* w, GdkEventKey* event)
 {
 	Application *pApp = m_pDoc->GetApplication ();
 	Tool *pActiveTool = pApp->GetActiveTool ();
+	if (pActiveTool->OnKeyRelease (event))
+		return true;
 	switch(event->keyval) {
 	case GDK_Shift_L:
 	case GDK_Shift_R:
@@ -903,9 +863,7 @@ void View::ExportImage (string const &filename, const char* type, int resolution
 		GError *error = NULL;
 		GsfOutput *output = gsf_output_gio_new_for_uri (filename.c_str (), &error);
 		if (error) {
-			gchar * mess = g_strdup_printf (_("Could not create stream!\n%s"), error->message);
-			GtkWidget* message = gtk_message_dialog_new (GTK_WINDOW (gtk_widget_get_toplevel (m_pWidget)), GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, mess);
-			g_free (mess);
+			GtkWidget* message = gtk_message_dialog_new (GTK_WINDOW (gtk_widget_get_toplevel (m_pWidget)), GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, _("Could not create stream!\n%s"), error->message);
 			gtk_dialog_run (GTK_DIALOG (message));
 			gtk_widget_destroy (message);
 			g_error_free (error);
@@ -931,9 +889,7 @@ void View::ExportImage (string const &filename, const char* type, int resolution
 		GError *error = NULL;
 		GsfOutput *output = gsf_output_gio_new_for_uri (filename.c_str (), &error);
 		if (error) {
-			gchar * mess = g_strdup_printf (_("Could not create stream!\n%s"), error->message);
-			GtkWidget* message = gtk_message_dialog_new (GTK_WINDOW (gtk_widget_get_toplevel (m_pWidget)), GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, mess);
-			g_free (mess);
+			GtkWidget* message = gtk_message_dialog_new (GTK_WINDOW (gtk_widget_get_toplevel (m_pWidget)), GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, _("Could not create stream!\n%s"), error->message);
 			gtk_dialog_run (GTK_DIALOG (message));
 			gtk_widget_destroy (message);
 			g_error_free (error);
@@ -1041,14 +997,16 @@ void View::EnsureSize ()
 {
 	double x1, y1, x2, y2;
 	m_Canvas->GetRoot ()->GetBounds (x1, y1, x2, y2);
-	if (x1 < 0.0) x2 -= x1;
-	if (y1 < 0.0) y2 -= y1;
+	if (x1 < 0.) x2 -= x1;
+	if (y1 < 0.) y2 -= y1;
+	if (x2 <= 0. || y2 <= 0.)
+		return;
 	if ((x2 != m_width) || (y2 != m_height)) {
 		m_width = x2;
 		m_height = y2;
 		gtk_widget_set_size_request (m_pWidget, (int) ceil (x2 * m_Canvas->GetZoom ()), (int) ceil (y2 * m_Canvas->GetZoom ()));
 	}
-	if ((x1 < 0.0) || (y1 < 0.0))
+	if ((x1 < 0.) || (y1 < 0.))
 	{
 		Theme* pTheme = m_pDoc->GetTheme ();
 		x1 = (x1 < 0.)? -x1 / pTheme->GetZoomFactor (): 0.;
@@ -1176,7 +1134,8 @@ bool View::OnButtonReleased (G_GNUC_UNUSED gccv::ItemClient *client, unsigned bu
 			break;
 		m_Dragging = false;
 		pActiveTool->OnRelease (x, y, state);
-		m_pDoc->GetApplication ()->ClearStatus ();
+		if (!pActiveTool->GetOwnStatus ())
+			m_pDoc->GetApplication ()->ClearStatus ();
 		return true;
 	}
 	return true;
@@ -1205,7 +1164,7 @@ bool View::OnMotion (gccv::ItemClient *client, double x, double y, unsigned stat
 	Application *App = m_pDoc->GetApplication ();
 	Tool* pActiveTool = App? App->GetActiveTool (): NULL;	
 	if (m_pDoc->GetEditable () && pActiveTool)
-		pActiveTool->OnMotion (this, m_CurObject, x, y, state);
+		pActiveTool->OnMotion (this, ((m_CurAtom)? m_CurAtom: m_CurObject), x, y, state);
 	return true;
 }
 
@@ -1213,7 +1172,7 @@ void View::SetSelectionState (Object *object, int state)
 {
 	gccv::ItemClient *client = dynamic_cast <gccv::ItemClient *> (object);
 	if (client)
-		client->SetSelected (state);
+		client->SetSelected (state);	
 	map<string, Object*>::iterator i;
 	Object *child = object->GetFirstChild (i);
 	while (child) {
