@@ -27,13 +27,9 @@
 #include "cmd-context.h"
 #include "document.h"
 #include "loader.h"
-#include <goffice/goffice.h>
-#include <goffice/app/io-context.h>
-#include <goffice/utils/go-file.h>
+#include "ui-builder.h"
 #include <gsf/gsf-input-gio.h>
 #include <gsf/gsf-output-gio.h>
-#include <glade/glade.h>
-#include <gtk/gtk.h>
 #include <glib/gi18n-lib.h>
 #include <sys/stat.h>
 #include <cmath>
@@ -50,6 +46,24 @@ namespace gcu
 GOConfNode *Application::m_ConfDir = NULL;
 
 static set<Application *> Apps;
+WindowState Application::DefaultWindowState = NormalWindowState;
+	
+static void on_maximize_windows ()
+{
+	Application::DefaultWindowState = MaximizedWindowState;
+}
+
+static void on_full_screen ()
+{
+	Application::DefaultWindowState = FullScreenWindowState;
+}
+
+static GOptionEntry options[] = 
+{
+  {"full-screen", 'F', G_OPTION_FLAG_NO_ARG, G_OPTION_ARG_CALLBACK, (void*) on_full_screen, N_("Open new windows full screen"), NULL},
+  {"maximize", 'M', G_OPTION_FLAG_NO_ARG, G_OPTION_ARG_CALLBACK, (void*) on_maximize_windows, N_("Maximize new windows"), NULL},
+  {NULL, 0, 0, G_OPTION_ARG_NONE, NULL, NULL, NULL }
+};
 
 Application::Application (string name, string datadir, char const *help_name, char const *icon_name)
 {
@@ -102,6 +116,7 @@ Application::Application (string name, string datadir, char const *help_name, ch
 		l = l->next;
 	}
 	g_slist_free (formats);
+	RegisterOptions (options);
 }
 
 Application::~Application ()
@@ -111,6 +126,7 @@ Application::~Application ()
 		ClearDialogs (); // needed to cleanly stop goffice
 		go_conf_free_node (m_ConfDir);
 		m_ConfDir = NULL;
+		libgoffice_shutdown ();
 	}
 }
 
@@ -185,32 +201,33 @@ static void on_transparency_changed (GtkToggleButton *btn, Application *app)
 
 GtkWidget *Application::GetImageResolutionWidget ()
 {
-	GladeXML *xml = glade_xml_new (GLADEDIR"/image-resolution.glade", "res-table", NULL);
-	GtkWidget *w = glade_xml_get_widget (xml, "screen-lbl");
+	UIBuilder *builder = new UIBuilder (UIDIR"/image-resolution.ui", GETTEXT_PACKAGE);
+	GtkWidget *w = builder->GetWidget ("screen-lbl");
 	char *buf = g_strdup_printf (_("(screen resolution is %u)"), m_ScreenResolution);
 	gtk_label_set_text (GTK_LABEL (w), buf);
 	g_free (buf);
-	w = glade_xml_get_widget (xml, "res-btn");
+	w = builder->GetWidget ("res-btn");
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (w), m_ImageResolution);
 	g_signal_connect (G_OBJECT (w), "value-changed", G_CALLBACK (on_res_changed), this);
-	w = glade_xml_get_widget (xml, "transparent-btn");
+	w = builder->GetWidget ("transparent-btn");
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w), m_TransparentBackground);
 	g_signal_connect (G_OBJECT (w), "toggled", G_CALLBACK (on_transparency_changed), this);
-	w = glade_xml_get_widget (xml, "res-table");
-	g_object_unref (G_OBJECT (xml));
+	w = builder->GetRefdWidget ("res-table");
+	delete builder;
 	return w;
 }
 
 GtkWidget *Application::GetImageSizeWidget ()
 {
-	GladeXML *xml = glade_xml_new (GLADEDIR"/image-size.glade", "size-table", NULL);
-	GtkWidget *w = glade_xml_get_widget (xml, "width");
+	UIBuilder *builder = new UIBuilder (UIDIR"/image-size.ui", GETTEXT_PACKAGE);
+	GtkWidget *w = builder->GetWidget ("width");
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (w), m_ImageWidth);
 	g_signal_connect (G_OBJECT (w), "value-changed", G_CALLBACK (on_width_changed), this);
-	w = glade_xml_get_widget (xml, "height");
+	w = builder->GetWidget ("height");
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (w), m_ImageHeight);
 	g_signal_connect (G_OBJECT (w), "value-changed", G_CALLBACK (on_height_changed), this);
-	w = glade_xml_get_widget (xml, "size-table");
+	w = builder->GetRefdWidget ("size-table");
+	delete builder;
 	return w;
 }
 
@@ -259,7 +276,7 @@ ContentType Application::Load (std::string const &uri, const gchar *mime_type, D
 		g_error_free (error);
 		return ContentTypeUnknown;
 	}
-	IOContext *io = gnumeric_io_context_new (gcu_get_cmd_context ());
+	GOIOContext *io = go_io_context_new (gcu_get_cmd_context ());
 	ContentType ret = l->Read (Doc, input, mime_type, io);
 	g_object_unref (input);
 	g_object_unref (io);
@@ -278,14 +295,12 @@ bool Application::Save (std::string const &uri, const gchar *mime_type, Document
 		g_file_delete (file, NULL, &error);
 		if (error) {
 			char *unescaped = g_uri_unescape_string (uri.c_str (), NULL);
-			gchar * message = g_strdup_printf (_("Error while processing %s:\n%s"), unescaped, error->message);
+			GtkDialog* Box = GTK_DIALOG (gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, _("Error while processing %s:\n%s"), unescaped, error->message));
 			g_free (unescaped);
 			g_error_free (error);
-			GtkDialog* Box = GTK_DIALOG (gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, message));
 			gtk_window_set_icon_name (GTK_WINDOW (Box), IconName.c_str ());
 			gtk_dialog_run (Box);
 			gtk_widget_destroy (GTK_WIDGET (Box));
-			g_free (message);
 			g_object_unref (file);
 			return false;
 		}
@@ -298,7 +313,7 @@ bool Application::Save (std::string const &uri, const gchar *mime_type, Document
 	if (error) {
 		g_error_free (error);
 	}
-	IOContext*io  = gnumeric_io_context_new (gcu_get_cmd_context ());
+	GOIOContext *io  = go_io_context_new (gcu_get_cmd_context ());
 	bool ret = l->Write (const_cast <Document *> (Doc), output, mime_type, io, type);
 	g_object_unref (output);
 	g_object_unref (io);
@@ -315,4 +330,32 @@ GOConfNode *Application::GetConfDir ()
 	return m_ConfDir;
 }
 
+struct option_data {
+	GOptionEntry const *entries;
+	char const *translation_domain;
+};
+
+void Application::RegisterOptions (GOptionEntry const *entries, char const *translation_domain)
+{
+	struct option_data d;
+	d.entries = entries;
+	d.translation_domain = translation_domain;
+	m_Options.push_back (d);
+}
+
+void Application::AddOptions (GOptionContext *context)
+{
+	list<option_data>::iterator i, end = m_Options.end ();
+	for (i = m_Options.begin (); i != end; i++)
+		g_option_context_add_main_entries (context, (*i).entries, (*i).translation_domain);
+}
+
+Application *Application::GetDefaultApplication ()
+{
+	static Application *Default = NULL;
+	if (!Default)
+		Default = new Application ("gcu"); // the name is just arbitrary
+	return Default;
+}
+
 }	//	namespace gcu
