@@ -25,11 +25,14 @@
 #include "config.h"
 #include "element.h"
 #include "crystalatom.h"
+#include "document.h"
 #include "element.h"
+#include "objprops.h"
 #include "xml-utils.h"
 #include <GL/glu.h>
 #include <cmath>
 #include <string>
+#include <sstream>
 
 namespace gcu
 {
@@ -98,6 +101,7 @@ CrystalAtom& CrystalAtom::operator=(CrystalAtom& caAtom)
 	m_fAlpha = caAtom.m_fAlpha ;
 	m_EffectiveRadiusRatio = caAtom.m_EffectiveRadiusRatio;
 	m_nCleave = 0 ;
+	SetCharge (caAtom.GetCharge ());
 	return *this ;
 }
 
@@ -149,9 +153,12 @@ double CrystalAtom::GetSize()
 
 bool CrystalAtom::operator==(CrystalAtom& caAtom)
 {
-	return (x() == caAtom.x()) &&
-			(y() == caAtom.y()) &&
-			(z() == caAtom.z()) ;
+	// original version only checked x, y and z, we might need a SameCoords method.
+	return ((fabs (x() - caAtom.x()) < PREC) &&
+			(fabs (y() - caAtom.y()) < PREC) &&
+			(fabs (z() - caAtom.z()) < PREC) &&
+			(GetZ () == caAtom.GetZ ()) &&
+			(GetCharge () == caAtom.GetCharge ())) ;
 }
 
 double CrystalAtom::ScalProd(int h, int k, int l)
@@ -215,4 +222,49 @@ void CrystalAtom::SetRadius(const GcuAtomicRadius& r)
 	m_Radius.spin = r.spin;
 }
 
+bool CrystalAtom::SetProperty (unsigned property, char const *value)
+{
+	switch (property) {
+	case GCU_PROP_POS2D:
+	case GCU_PROP_X:
+	case GCU_PROP_Y:
+	case GCU_PROP_Z:
+		break;
+	case GCU_PROP_XFRACT:
+		m_x = strtod (value, NULL) * GetDocument ()->GetScale ();
+		break;
+	case GCU_PROP_YFRACT:
+		m_y = strtod (value, NULL) * GetDocument ()->GetScale ();
+		break;
+	case GCU_PROP_ZFRACT:
+		m_z = strtod (value, NULL) * GetDocument ()->GetScale ();
+		break;
+	default:
+		return Atom::SetProperty (property, value);
+	}
+	return  true;
+}
+
+std::string CrystalAtom::GetProperty (unsigned property) const
+{
+	std::ostringstream res;
+	switch (property) {
+	case GCU_PROP_ATOM_CHARGE:
+		res << static_cast <int> (m_Radius.charge);
+		break;
+	case GCU_PROP_XFRACT:
+		res << x ();
+		break;
+	case GCU_PROP_YFRACT:
+		res << y ();
+		break;
+	case GCU_PROP_ZFRACT:
+		res << z ();
+		break;
+	default:
+		return Atom::GetProperty (property);
+	}
+	return res.str ();
+};
+
 }	//	namespace gcu
