@@ -23,14 +23,10 @@
 #include "config.h"
 #include "gtkperiodic.h"
 #include "chemistry.h"
+#include <goffice/goffice.h>
 #include <string.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <gtk/gtkstyle.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtknotebook.h>
-#include <glade/glade.h>
-#include <glib/garray.h>
 #include <glib/gi18n-lib.h>
 
 struct _GtkPeriodic
@@ -127,6 +123,7 @@ gtk_periodic_get_type (void)
 			sizeof (GtkPeriodic),
 			0,              /* n_preallocs */
 			(GInstanceInitFunc) gtk_periodic_init,
+			NULL
 		};
 
 		periodic_type = g_type_register_static (GTK_TYPE_BIN, "GtkPeriodic", &periodic_info, 0);
@@ -174,34 +171,28 @@ void gtk_periodic_class_init (GtkPeriodicClass *klass)
 
 void gtk_periodic_init (GtkPeriodic *periodic)
 {
-	GladeXML* xml;
+	GtkBuilder* xml;
 	GtkStyle* style;
 	char name[8] = "elt";
 	GtkToggleButton* button;
 	int i;
-	char* domain = g_strdup(textdomain(NULL));
-	textdomain(GETTEXT_PACKAGE);
-	xml =  glade_xml_new(GLADEDIR"/gtkperiodic.glade", "vbox1", NULL);
+	xml = go_gtk_builder_new (UIDIR"/gtkperiodic.ui", GETTEXT_PACKAGE, NULL);
 	g_return_if_fail (xml);
-	g_object_set_data(G_OBJECT(periodic), "xml", xml);
-	glade_xml_signal_autoconnect (xml);
-	periodic->vbox = GTK_VBOX(glade_xml_get_widget(xml, "vbox1"));
-	periodic->book = GTK_NOTEBOOK (glade_xml_get_widget (xml, "book"));
+	periodic->vbox = GTK_VBOX (gtk_builder_get_object (xml, "vbox1"));
+	periodic->book = GTK_NOTEBOOK (gtk_builder_get_object (xml, "book"));
 	periodic->colorstyle = GTK_PERIODIC_COLOR_NONE;
-	memset(periodic->buttons, 0, sizeof(GtkToggleButton*) * 119);
-	for (i = 1; i <= 118; i++)
-	{
+	memset(periodic->buttons, 0, sizeof (GtkToggleButton*) * 119);
+	for (i = 1; i <= 118; i++) {
 		sprintf(name + 3, "%d", i);
-		button = (GtkToggleButton*)glade_xml_get_widget(xml, name);
-		if (GTK_IS_TOGGLE_BUTTON(button))
-		{
+		button = (GtkToggleButton*) gtk_builder_get_object (xml, name);
+		if (GTK_IS_TOGGLE_BUTTON (button)) {
 			gtk_widget_set_tooltip_text (GTK_WIDGET(button), gcu_element_get_name(i));
 			periodic->buttons[i] = button;
 			periodic->labels[i] = GTK_LABEL (gtk_bin_get_child (GTK_BIN (button)));
-			g_signal_connect(G_OBJECT(button), "toggled", (GCallback)on_clicked, periodic);
+			g_signal_connect (G_OBJECT (button), "toggled", G_CALLBACK (on_clicked), periodic);
 		}
 	}
-	style = gtk_style_copy(gtk_widget_get_style(GTK_WIDGET(periodic->buttons[1])));
+	style = gtk_style_copy (gtk_widget_get_style (GTK_WIDGET (periodic->buttons[1])));
 	DefaultRed[0] = style->bg[0].red;
 	DefaultGreen[0] = style->bg[0].green;
 	DefaultBlue[0] = style->bg[0].blue;
@@ -214,22 +205,19 @@ void gtk_periodic_init (GtkPeriodic *periodic)
 	DefaultRed[3] = style->bg[3].red;
 	DefaultGreen[3] = style->bg[3].green;
 	DefaultBlue[3] = style->bg[3].blue;
-	g_object_unref(style);
+	g_object_unref (style);
 	periodic->Z = 0;
-	gtk_container_add(GTK_CONTAINER(periodic), GTK_WIDGET(periodic->vbox));
-	gtk_widget_show_all(GTK_WIDGET(periodic));
-	textdomain(domain);
-	g_free(domain);
+	gtk_container_add (GTK_CONTAINER (periodic), GTK_WIDGET (periodic->vbox));
+	gtk_widget_show_all (GTK_WIDGET (periodic));
 	periodic->colorschemes = g_array_new (FALSE, FALSE, sizeof (struct ColorScheme));
+	g_object_unref (xml);
 }
 
 static void gtk_periodic_finalize (GObject *object)
 {
 	GtkPeriodic *periodic = (GtkPeriodic*) object;
-	GObject *obj = (GObject*) g_object_get_data (object, "xml");
 
 	g_array_free (periodic->colorschemes, FALSE);
-	if (obj) g_object_unref (obj);
 
 	if (G_OBJECT_CLASS (parent_class)->finalize)
 		(* G_OBJECT_CLASS (parent_class)->finalize) (object);
@@ -269,14 +257,18 @@ void on_clicked(GtkToggleButton *button, GtkPeriodic* periodic)
 
 void gtk_periodic_size_allocate(GtkPeriodic* w, GtkAllocation *allocation)
 {
-	if (GTK_BIN(w)->child && GTK_WIDGET_VISIBLE (GTK_BIN(w)->child))
-		gtk_widget_size_allocate (GTK_BIN(w)->child, allocation);
+	GtkWidget *widget = gtk_bin_get_child (GTK_BIN (w));
+	gboolean visible = FALSE;
+	if (widget)
+		g_object_get (G_OBJECT (widget), "visible", &visible, NULL);
+	if (visible)
+		gtk_widget_size_allocate (widget, allocation);
 	(GTK_WIDGET_CLASS(parent_class))->size_allocate(GTK_WIDGET(w), allocation);
 }
 
 void gtk_periodic_size_request(GtkPeriodic* w, GtkRequisition *requisition)
 {
-	gtk_widget_size_request ((GTK_BIN(w))->child, requisition);
+	gtk_widget_size_request (gtk_bin_get_child (GTK_BIN (w)), requisition);
 }
 
 guint gtk_periodic_get_element(GtkPeriodic* periodic)
@@ -320,7 +312,7 @@ gtk_periodic_set_property (GObject              *object,
 		break;
 
 	case PROP_COLOR_STYLE: {
-		int style = g_value_get_uint (value);
+		unsigned style = g_value_get_uint (value);
 		if (style < GTK_PERIODIC_COLOR_MAX + periodic->nbschemes) {
 			periodic->colorstyle = style;
 			int page = (style >= GTK_PERIODIC_COLOR_MAX)? 
