@@ -24,7 +24,6 @@
 #include "gtkspectrumviewer.h"
 #include "spectrumdoc.h"
 #include "spectrumview.h"
-#include <goffice/gtk/go-graph-widget.h>
 #include <gsf/gsf-impl-utils.h>
 #include <gtk/gtkbin.h>
 
@@ -44,8 +43,12 @@ struct _GtkSpectrumViewerClass
 static void
 on_size (GtkSpectrumViewer* w, GtkAllocation *allocation, G_GNUC_UNUSED gpointer user_data)
 {
-	if (GTK_BIN (w)->child && GTK_WIDGET_VISIBLE (GTK_BIN (w)->child))
-		gtk_widget_size_allocate (GTK_BIN (w)->child, allocation);
+	GtkWidget *widget = gtk_bin_get_child (GTK_BIN (w));
+	bool visible = false;
+	if (widget)
+		g_object_get (G_OBJECT (widget), "visible", &visible, NULL);
+	if (visible)
+		gtk_widget_size_allocate (widget, allocation);
 }
 
 GtkWidget*
