@@ -83,6 +83,15 @@ Object::~Object ()
 	}
 }
 
+void Object::Clear ()
+{
+	map<string, Object*>::iterator i;
+	while (!m_Children.empty ()) {
+		(*i).second->m_Parent = NULL;
+		delete (*i).second;
+		m_Children.erase ((*i).first);
+	}
+}
 
 void Object::SetId (gchar const *Id)
 {
